# Copyright (C) 2024 Maxwell G <maxwell@gtmx.me>
# SPDX-License-Identifier: MIT
# License text: https://spdx.org/licenses/MIT

%bcond manpages 1
# Whether to build the scancode extra
%bcond scancode %{defined fedora}
# Only run scancode tests when arch is not i386
%bcond scancode_tests %[ %{with scancode} && "%{_arch}" != "i386"]

%global forgeurl https://gitlab.com/fedora/sigs/go/go-vendor-tools
%define tag v%{version_no_tilde %{quote:%nil}}

Name:           go-vendor-tools
Version:        0.6.0^88.20250320.ac7aad8
%forgemeta
Release:        1%{?dist}
Summary:        Tools for handling Go library vendoring in Fedora [SEE NOTE IN DESCRIPTION]

# BSD-3-Clause: src/go_vendor_tools/archive.py
License:        MIT AND BSD-3-Clause
URL:            %{forgeurl}
Source0:        go-vendor-tools-0.6.0^88.20250320.ac7aad8.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel

# Test dependencies
BuildRequires:  askalono-cli
BuildRequires:  trivy

%if %{with manpages}
BuildRequires:  scdoc
%endif

Recommends:     (askalono-cli or trivy or go-vendor-tools+scancode)
Recommends:     go-vendor-tools+all


%global common_description %{expand:
go-vendor-tools provides tools and macros for handling Go library vendoring in
Fedora.

STABILITY NOTE:

go-vendor-tools is under active development and available in the stable Fedora
and Fedora EPEL repos for testing purposes.
Expect some breaking changes between releases.
Anyone using the `%%go_vendor_*` macros in active Fedora packages MUST join the
Fedora Golang Matrix room and Fedora Go SIG mailing list to be notified of any
major changes.}

%description %common_description


%package doc
Summary:        Documentation for go-vendor-tools
Enhances:       go-vendor-tools

%description doc %common_description


%prep
%autosetup -p1 


%generate_buildrequires
%pyproject_buildrequires -x all,test%{?with_scancode_tests:,scancode}


%build
%pyproject_wheel
%if %{with manpages}
./doc/man/mkman.sh
%endif

mkdir -p bash_completions fish_completions zsh_completions
for bin in go_vendor_archive go_vendor_license; do
    register-python-argcomplete --shell bash "${bin}" > "bash_completions/${bin}"
    register-python-argcomplete --shell fish "${bin}" > "fish_completions/${bin}.fish"
    # Compatibility with old argcomplete versions
    if ! (register-python-argcomplete --shell zsh "${bin}" > "zsh_completions/_${bin}"); then
        echo "#compdef ${bin}" > "zsh_completions/_${bin}"
        echo -e "autoload -Uz bashcompinit\nbashcompinit" > "zsh_completions/_${bin}"
        cat "bash_completions/${bin}" >> "zsh_completions/_${bin}"
    fi
done


%install
%pyproject_install
# TODO(anyone): Use -l flag once supported by EL 9.
%pyproject_save_files go_vendor_tools

# Install RPM macros
install -Dpm 0644 rpm/macros.go_vendor_tools -t %{buildroot}%{_rpmmacrodir}

# Install documentation
mkdir -p %{buildroot}%{_docdir}/go-vendor-tools-doc
cp -rL doc/* %{buildroot}%{_docdir}/go-vendor-tools-doc

# Install manpages
%if %{with manpages}
install -Dpm 0644 doc/man/*.1 -t %{buildroot}%{_mandir}/man1/
install -Dpm 0644 doc/man/*.5 -t %{buildroot}%{_mandir}/man5/
%endif

# Install completions
install -Dpm 0644 bash_completions/* -t %{buildroot}%{bash_completions_dir}/
install -Dpm 0644 fish_completions/* -t %{buildroot}%{fish_completions_dir}/
install -Dpm 0644 zsh_completions/* -t %{buildroot}%{zsh_completions_dir}/


%check
export MACRO_DIR=%{buildroot}%{_rpmmacrodir}
%pytest


%files -f %{pyproject_files}
# Install top-level markdown files
%doc *.md
%license LICENSES/*
%{_bindir}/go_vendor*
%{bash_completions_dir}/go_vendor_*
%{fish_completions_dir}/go_vendor_*.fish
%{zsh_completions_dir}/_go_vendor_*
%{_rpmmacrodir}/macros.go_vendor_tools
%if %{with manpages}
%{_mandir}/man1/go*.1*
%{_mandir}/man5/go*.5*
%endif

%files doc
%doc %{_docdir}/go-vendor-tools-doc/

%pyproject_extras_subpkg -n go-vendor-tools all %{?with_scancode:scancode}

%changelog
* Thu Mar 20 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^88.20250320.ac7aad8-1
- Revert "debug pytest in specfile. outdated scancode is causing issues."

* Thu Mar 20 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^87.20250320.f02f10c-1
- test_load_dump_license_data: don't test detector-specific data

* Wed Mar 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^86.20250319.4de7062-1
- tests: make compatible with older scancode

* Wed Mar 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^85.20250319.d05732c-1
- lint: fix PLW1508 Invalid type for environment variable default

* Tue Mar 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^84.20250318.8a81f92-1
- lint specfile: fix internal _ContentContext Protocol

* Tue Mar 04 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^83.20250304.b4bd04c-1
- debug pytest in specfile. outdated scancode is causing issues.

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^82.20250302.4e83c77-1
- lint tests: remove outdated comment

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^81.20250302.b8e3ab3-1
- packaging: run full unit test suite

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^80.20250302.023d903-1
- lint rpm: wrap text for increased readability

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^79.20250302.4a42b1a-1
- rpm: use shescape where it's available

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^78.20250302.fd08d5c-1
- doc: fix mis-formatted copyright statement

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^77.20250302.3e10d5c-1
- doc rpm_macros: add example for %%go_vendor_license_install

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^76.20250302.7149e82-1
- cli license: determine whether failure occurred after prompting

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^75.20250302.8642866-1
- license_detection trivy: fix handling of undetected licenses

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^74.20250302.2bfa099-1
- lint: doc rpm_macros

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^73.20250302.1798c06-1
- doc: remove redundant docs from navbar

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^72.20250302.efe0ead-1
- licensing compare_licenses: allow more invalid expressions

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^71.20250302.2487b70-1
- packaging: add scancode extra

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^70.20250302.958fc78-1
- doc config: remove scancode warning

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^69.20250302.c939ef3-1
- ci: no-error-on-missing-interpreters on EL 9

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^68.20250302.12967ca-1
- tests test_load_dump_license_data: fix sporadic failure

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^67.20250302.148ba38-1
- ci: get rid of Fedora 39

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^66.20250302.4e2c15f-1
- rpm: get rid of shescape that's unavailable on EL 9

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^65.20250302.7ae39dc-1
- license_detection scancode: sort data to fix tests

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^64.20250302.482258a-1
- license_detection scancode: change type of scancode_license_data

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^63.20250302.cbfc7a4-1
- fixup! license_detection askalono: sort output for consistent test results

* Sun Mar 02 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^62.20250302.ce83461-1
- ci: run unit tests first

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^61.20250226.925bd64-1
- license_detection askalono: sort output for consistent test results

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^60.20250226.7d6b88f-1
- fixup! license_detection search: include LICENSE.docs in root directory

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^59.20250226.33268d7-1
- cli license: --prompt should imply --write-config

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^58.20250226.7c7cade-1
- rpm: remove wrapping and expr

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^57.20250226.c5cd799-1
- license_detection search: include LICENSE.docs in root directory

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^56.20250226.1ee8a0b-1
- license_detection scancode; remove unused constants

* Wed Feb 26 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^55.20250226.bac1f05-1
- lint basedpyright: remove duplicate pyproject configuration

* Mon Feb 24 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^54.20250224.b159157-1
- doc rpm_macros: update go_vendor_license_check_disable example

* Mon Feb 24 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^53.20250224.288c40b-1
- doc rpm_macros: fix typo (2)

* Mon Feb 24 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^52.20250224.eebbd34-1
- doc rpm_macros: fix typo

* Thu Feb 20 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^51.20250220.5cbfced-1
- license_detection find_license_files: error for invalid manual entries

* Thu Feb 20 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^50.20250220.c160033-1
- doc: document RPM macros

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^49.20250219.a164b51-1
- doc: add go_vendor_license markdown docs

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^48.20250219.7c2e81e-1
- doc: add manpages for `go_vendor_license` and config

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^47.20250219.5288c4c-1
- license_detection: add detector_name to license data dict

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^46.20250219.8eec404-1
- cli license --update-spec: don't update if detection failed

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^45.20250219.300df05-1
- cli license: add help message

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^44.20250219.0b37b3e-1
- licensing compare_licenses: don't validate licenses

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^43.20250219.c18a042-1
- load get_detctors: fix typo in function name

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^42.20250219.2a300bb-1
- rpm: check for go_vendor_license_check_disable truthiness ...

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^41.20250219.8be62e1-1
- cli license: write detector_config when --write-config is enabled

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^40.20250219.ee7dab9-1
- licensing: add detector_config option

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^39.20250219.81c0536-1
- doc: document pre_commands and post_commands

* Wed Feb 19 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^38.20250219.d4459d6-1
- license_detection: support askalono --multiple and test REUSE

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^37.20250218.6006f52-1
- Revert "[wip] license_detection: workaround vendor.txt requirement"

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^36.20250218.32b86ae-1
- ci packit: disable osh scan

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^35.20250218.da9ede5-1
- tests: add missing specfile dependency

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^34.20250218.78a9655-1
- Implement go_vendor_license_check_disable

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^33.20250218.281fb50-1
- cli: make tomlkit optional again

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^32.20250218.5861371-1
- cli: make tomlkit optional again

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^31.20250218.f94034e-1
- lint basedpyright: exclude .nox from linting

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^30.20250218.972ff72-1
- specfile: make python3-specfile optional

* Tue Feb 18 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^29.20250218.407488a-1
- Add specfile module; allow updating specfile license

* Mon Feb 17 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^28.20250217.525b8d3-1
- specfile_sources: add docstrings

* Sun Feb 16 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^27.20250216.307b11c-1
- cli: catch_vendor_tools_error

* Sun Feb 16 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^26.20250216.f25cb12-1
- lint nox: fix typing errors with latest nox

* Sun Feb 16 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^25.20250216.865079b-1
- archive create: don't leave empty archive file if creation fails

* Sun Feb 16 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^24.20250216.8ee8125-1
- cli archive: add comment marking args loaded from config options

* Sun Feb 09 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^23.20250209.9de77fb-1
- nox bump: re-enable twine check

* Sun Feb 09 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^22.20250209.82f3a37-1
- ci: allow disabling scancode tests

* Sun Feb 09 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^21.20250209.3589fd1-1
- Finish implementing detect_only support

* Fri Feb 07 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^20.20250207.887e9a8-1
- lint: format with new black style

* Fri Feb 07 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^19.20250207.9ba9aca-1
- contrib devenv: add ipython

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^18.20250129.a768606-1
- license_detection: initial detect_only mode support

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^17.20250129.34ee2e9-1
- license_detection: cleanup trivy code and initial REUSE support

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^16.20250129.1a17717-1
- ci: temporarily disable Fedora Rawhide

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^15.20250129.ce0bf62-1
- ci: update Matrix for Fedora 41

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^14.20250129.92a0de8-1
- [wip] license_detection: workaround vendor.txt requirement

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^13.20250129.8bf9550-1
- [wip] license_detection: add TODO comments

* Wed Jan 29 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^12.20250129.64d5117-1
- [wip] license_detection: use consistent method to find license files

* Tue Jan 21 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^11.20250121.89aa428-1
- dev doc README: fix dev branch name

* Tue Jan 21 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^10.20250121.63858f2-1
- dev doc README: add active development note

* Fri Jan 17 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^9.20250117.3bc8ea6-1
- internal contrib: add missing executable bit to script

* Fri Jan 17 2025 Maxwell G <maxwell@gtmx.me> - 0.6.0^8.20250117.d68271a-1
- dev: add devenv script

* Thu Dec 12 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^7.20241212.bdb6d6e-1
- doc: enable search

* Wed Oct 02 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^6.20241002.722c983-1
- doc scenarios: adjust generate specfile example

* Mon Sep 23 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^5.20240923.fc29f2d-1
- doc example-specfile: update go_vendor_archive create usage

* Tue Sep 10 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^4.20240910.c483b94-1
- packaging: remove scancode-toolkit dependency

* Sun Sep 08 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^3.20240908.2fb1fb2-1
- doc mkdocs: add meta tag for site description

* Sun Sep 08 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^2.20240908.6ea1338-1
- doc README: remove incorrect Fedora EPEL reference

* Wed Aug 28 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0^1.20240828.cbc179f-1
- Post-release version bump

* Wed Aug 28 2024 Maxwell G <maxwell@gtmx.me> - 0.6.0-1
- Release 0.6.0.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.1-1
- Release 0.5.1.

* Thu Apr 11 2024 Maxwell G <maxwell@gtmx.me> - 0.5.0-1
- Release 0.5.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0-1
- Release 0.4.0.

* Wed Apr 10 2024 Maxwell G <maxwell@gtmx.me> - 0.4.0~b1-1
- Release 0.4.0b1.

* Thu Mar 28 2024 Maxwell G <maxwell@gtmx.me> - 0.3.0-1
- Release 0.3.0.

* Sat Mar 16 2024 Maxwell G <maxwell@gtmx.me> - 0.2.0-1
- Release 0.2.0.

* Sat Mar 09 2024 Maxwell G <maxwell@gtmx.me> - 0.1.0-1
- Release 0.1.0.

* Tue Mar 05 2024 Maxwell G <maxwell@gtmx.me> - 0.0.1-1
- Release 0.0.1.
